keyboard_sticky library

Classes

DelegatedKeyboardStickyState
KeyboardSticky
A widget that sticks to the keyboard when the keyboard would overlap or hide it.
KeyboardStickyBuilderDelegate
KeyboardStickyChildBuilderDelegate
A delegate that builds child or floating child of KeyboardSticky with a custom builder.

Typedefs

KeyboardStickyFieldBuilder = TextField Function(BuildContext context, TextEditingController controller, FocusNode focusNode)
KeyboardStickyWrapperBuilder = Widget Function(BuildContext context, KeyboardStickyController controller, TextField? field)